public inbox for u-boot@lists.denx.de
 help / color / mirror / Atom feed
* [U-Boot] [PATCH v2 1/5] sunxi: R40: add gigabit ethernet clocks
@ 2018-04-17 13:42 Lothar Felten
  2018-04-17 13:42 ` [U-Boot] [PATCH v2 2/5] sunxi: R40: add gigabit ethernet reset Lothar Felten
                   ` (4 more replies)
  0 siblings, 5 replies; 11+ messages in thread
From: Lothar Felten @ 2018-04-17 13:42 UTC (permalink / raw)
  To: u-boot

Add clock control entries for the gigabit interface of the Allwinner
R40/V40 CPU

Signed-off-by: Lothar Felten <lothar.felten@gmail.com>
---
 arch/arm/include/asm/arch-sunxi/clock_sun6i.h | 10 +++++++++-
 1 file changed, 9 insertions(+), 1 deletion(-)

diff --git a/arch/arm/include/asm/arch-sunxi/clock_sun6i.h b/arch/arm/include/asm/arch-sunxi/clock_sun6i.h
index d35aa479f7..3ea473c302 100644
--- a/arch/arm/include/asm/arch-sunxi/clock_sun6i.h
+++ b/arch/arm/include/asm/arch-sunxi/clock_sun6i.h
@@ -61,7 +61,11 @@ struct sunxi_ccm_reg {
 	u32 reserved11;
 	u32 sata_clk_cfg;	/* 0xc8 SATA clock control (R40 only) */
 	u32 usb_clk_cfg;	/* 0xcc USB clock control */
-	u32 gmac_clk_cfg;	/* 0xd0 GMAC clock control */
+#ifdef CONFIG_MACH_SUN8I_R40
+	u32 cir0_clk_cfg;	/* 0xd0 CIR0 clock control (R40 only) */
+#else
+	u32 gmac_clk_cfg;	/* 0xd0 GMAC clock control (not for R40) */
+#endif
 	u32 reserved12[7];
 	u32 mdfs_clk_cfg;	/* 0xf0 MDFS clock control */
 	u32 dram_clk_cfg;	/* 0xf4 DRAM configuration clock control */
@@ -104,7 +108,11 @@ struct sunxi_ccm_reg {
 	u32 mtc_clk_cfg;	/* 0x158 MTC module clock */
 	u32 mbus0_clk_cfg;	/* 0x15c MBUS0 module clock */
 	u32 mbus1_clk_cfg;	/* 0x160 MBUS1 module clock */
+#ifdef CONFIG_MACH_SUN8I_R40
+	u32 gmac_clk_cfg;	/* 0x164 GMAC clock control (R40 only) */
+#else
 	u32 reserved16;
+#endif
 	u32 mipi_dsi_clk_cfg;	/* 0x168 MIPI DSI clock control */
 	u32 mipi_csi_clk_cfg;	/* 0x16c MIPI CSI clock control */
 	u32 reserved17[4];
-- 
2.14.1

^ permalink raw reply related	[flat|nested] 11+ messages in thread

end of thread, other threads:[~2018-04-23 17:39 UTC | newest]

Thread overview: 11+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2018-04-17 13:42 [U-Boot] [PATCH v2 1/5] sunxi: R40: add gigabit ethernet clocks Lothar Felten
2018-04-17 13:42 ` [U-Boot] [PATCH v2 2/5] sunxi: R40: add gigabit ethernet reset Lothar Felten
2018-04-19  8:35   ` Maxime Ripard
2018-04-17 13:42 ` [U-Boot] [PATCH v2 3/5] sunxi: R40: add gigabit ethernet gpio pinmux Lothar Felten
2018-04-19  8:35   ` Maxime Ripard
2018-04-17 13:42 ` [U-Boot] [PATCH v2 4/5] sunxi: R40: add gigabit ethernet devicetree node Lothar Felten
2018-04-19  8:40   ` Maxime Ripard
2018-04-17 13:42 ` [U-Boot] [PATCH v2 5/5] configs: Bananapi_M2_Ultra: enable gigabit on the Bananapi M2U Lothar Felten
2018-04-19  8:41   ` Maxime Ripard
2018-04-23 17:39     ` Lothar Felten
2018-04-19  8:34 ` [U-Boot] [PATCH v2 1/5] sunxi: R40: add gigabit ethernet clocks Maxime Ripard

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox